### Name: grad.desc
### Title: Gradient Descent Algorithm for the 2D Case
### Aliases: grad.desc
### Keywords: optimize dynamic dplot

### ** Examples

# default example 
oopt = ani.options(interval = 0.3, nmax = 50)
xx = grad.desc()
xx$par  # solution
xx$persp(col = "lightblue", phi = 30)   # perspective plot 

# define more complex functions; a little time-consuming 
f1 = function(x, y) x^2 + 3 * sin(y) 
xx = grad.desc(f1, pi * c(-2, -2, 2, 2), c(-2 * pi, 2)) 
xx$persp(col = "lightblue", theta = 30, phi = 30)
# or 
ani.options(interval = 0, nmax = 200)
f2 = function(x, y) sin(1/2 * x^2 - 1/4 * y^2 + 3) * 
    cos(2 * x + 1 - exp(y))  
xx = grad.desc(f2, c(-2, -2, 2, 2), c(-1, 0.5), 
    gamma = 0.1, tol = 1e-04)

## Not run:  
##D # click your mouse to select a start point 
##D xx = grad.desc(f2, c(-2, -2, 2, 2), interact = TRUE, 
##D     tol = 1e-04)
##D xx$persp(col = "lightblue", theta = 30, phi = 30)
##D 
##D # HTML animation pages 
##D ani.options(ani.height = 500, ani.width = 500, outdir = getwd(), interval = 0.3,
##D     nmax = 50, title = "Demonstration of the Gradient Descent Algorithm",
##D     description = "The arrows will take you to the optimum step by step.")
##D ani.start()
##D grad.desc()
##D ani.stop()
## End(Not run)

ani.options(oopt)



