### Name: moving.block
### Title: Cycle Through an R Object and Plot Each Subset of Elements
### Aliases: moving.block
### Keywords: dynamic hplot

### ** Examples

## Brownian motion
#  block length: 101 (i.e. 300-200+1)
oopt = ani.options(nmax = 200, interval = 0.1)
#  plot y = dat against x = i + 1:block
#  customize xlab and ylab with 'i' and 'block'
#  restrict ylim using the range of 'dat'
moving.block(dat = cumsum(rnorm(300)), FUN = function(..., 
    dat = dat, i = i, block = block) {
    plot(..., x = i + 1:block, xlab = sprintf("block length = %d", 
        block), ylim = range(dat), ylab = sprintf("x[%s:%s]", 
        i + 1, i + block))
}, type = "o", pch = 20) 

## Word counts of Hu's speech 
#  see any pattern in the President's speech? 
ani.options(nmax = 66, interval = 0.5)
data(HuSpeech)
moving.block(dat = HuSpeech, FUN = function(..., dat = dat, 
    i = i, block = block) {
    plot(..., x = i + 1:block, xlab = "paragraph index", ylim = range(dat), 
        ylab = sprintf("HuSpeech[%s:%s]", i + 1, i + block))
}, type = "o", pch = 20) 

## Not run: 
##D ## sunspot data: observe the 11-year cycles
##D #  block = 11 years x 12 months/year = 132
##D #  set interval greater than 0 if your computer really rocks!
##D ani.options(nmax = 2857, interval = 0)
##D spt.att = tsp(sunspot.month)
##D #  the time index (we need it to correctly draw the ticks of x-axis)
##D ts.idx = seq(spt.att[1], spt.att[2], 1/spt.att[3])
##D moving.block(dat = sunspot.month, block = 132, FUN = function(..., 
##D     dat = dat, i = i, block = block) {
##D     plot(..., x = ts.idx[i + 1:block], xlab = sprintf("block length = %d", 
##D         block), ylim = range(dat), ylab = sprintf("sunspot.month[%s:%s]", 
##D         i + 1, i + block))
##D }, type = "o", pch = 20) 
## End(Not run)

## earth quake: order the data by 'depth' first
#  see how the locations change as 'depth' increases
ani.options(nmax = 900, interval = 0.01)
#  compute the mean depth for each block of data
moving.block(quakes[order(quakes$depth), c("long", "lat")], 
    FUN = function(..., dat = dat, i = i, block = block) {
    plot(..., xlab = sprintf("%s[%s:%s]", colnames(dat)[1], i + 
        1, i + block), ylab = sprintf("%s[%s:%s]", colnames(dat)[2], 
        i + 1, i + block), xlim = range(dat[, 1]), ylim = range(dat[, 
        2]), main = sprintf("Mean Depth = %.3f", mean(sort(quakes$depth)[i + 
        1:block])))
}, pch = 20, col = rgb(0, 0, 0, 0.5))

ani.options(oopt)



